package com.company.cloud.wx.sdk.work.model.member;

import cn.hutool.core.util.StrUtil;
import com.company.cloud.sdk.weixin.common.constant.BaseEnum;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.utils.EnumValid;
import lombok.Data;

import javax.validation.constraints.*;
import java.util.List;
import java.util.Map;

/**
 * 更新成员
 */
@Data
public class MemberUpdateModel extends BaseReqModel {
    /**
    *必传
     * 成员UserID。对应管理端的帐号，企业内必须唯一。不区分大小写，长度为1~64个字节。只能由数字、字母和“_-@.”四种字符组成，且第一个字符必须是数字或字母。
    */
    @NotEmpty(message = "成员UserID不能为空")
    @Max(value = 64,message = "userId长度不能超过64个字节")
    @Pattern(regexp = "/[a-zA-z0-9]{1}[-a-zA-z0-9@._]*/g",message = "只能由数字、字母和“_-@.”四种字符组成，且首字符为数字或字母")
    private String userid;
    /**
     * 必传
     * 成员名称。长度为1~64个utf8字符
    */
    @Max(value = 64,message = "名称长度不能超过64个字符")
    private String name;
    /**
    *成员别名。长度1~32个utf8字符
    */
    @Max(value = 32,message = "别名长度不能超过32个字符")
    private String alias;
    /**
    *手机号码。企业内必须唯一，mobile/email二者不能同时为空
    */
    @Pattern(regexp = "/[1]{1}[0-9]{10}/g",message = "手机号格式不正确")
    private String mobile;
    /**
    *成员所属部门id列表,不超过100个
    */
    @Max(100)
    private List<Integer> department;
    /**
    *部门内的排序值，默认为0，成员次序以创建时间从小到大排列。个数必须和参数department的个数一致，数值越大排序越前面。有效的值范围是[0, 2^32)
    */
    private List<Integer> order;
    /**
    *职务信息。长度为0~128个字符
    */
    @Max(128)
    private String position;
    /**
    *性别。1表示男性，2表示女性
    */
    @EnumValid(target = BaseEnum.GenderEnum.class,message = "性别传值非法")
    private String gender;
    /**
    *邮箱。长度6~64个字节，且为有效的email格式。企业内必须唯一，mobile/email二者不能同时为空
    */
    @Email
    private String email;
    /**
    *座机。32字节以内，由纯数字或’-‘号组成。
    */
    @Max(32)
    @Pattern(regexp = "/[-0-9]*/g")
    private String telephone;
    /**
     *mobile/email二者不能同时为空
     */
    @AssertTrue(message = "mobile/email二者不能同时为空")
    private Boolean isHaveContactInfo(){
        return StrUtil.isNotBlank(mobile)||StrUtil.isNotBlank(email);
    }

    /**
    *个数必须和参数department的个数一致，表示在所在的部门内是否为上级。1表示为上级，0表示非上级。在审批等应用里可以用来标识上级审批人
    */
    private List<Integer> is_leader_in_dept;
    /**
    *成员头像的mediaid，通过素材管理接口上传图片获得的mediaid
    */
    private String avatar_mediaid;
    /**
    *启用/禁用成员。1表示启用成员，0表示禁用成员
    */
    @EnumValid(target = BaseEnum.EnabledEnum.class,message = "启用标志非法")
    private Integer enable;
    /**
     *地址。长度最大128个字符
     */
    @Max(128)
    private String address;
    /**
     *主部门
     */
    private Integer main_department;
    /**
    *自定义字段。只支持type=0的文本和type=1的网页类型
    */
    private Map<String,Object> extattr;
    /**
    *成员对外属性
    */
    private Map<String,Object> external_profile;
    /**
    *对外职务，如果设置了该值，则以此作为对外展示的职务，否则以position来展示。长度12个汉字内
    */
    private String external_position;


}
